================
Authors of Kwant
================

The Kwant authors can be reached at authors@kwant-project.org.

The principal developers of Kwant are

* `Christoph W. Groth <mailto:christoph.groth@cea.fr>`_ (CEA Grenoble)
* `Michael Wimmer <https://michaelwimmer.org>`_ (TU Delft)
* `Anton R. Akhmerov <http://antonakhmerov.org>`_ (TU Delft)
* `Xavier Waintal <http://inac.cea.fr/Pisp/xavier.waintal>`_ (CEA Grenoble)
* `Joseph Weston <http://josephweston.org>`_ (TU Delft)

Contributors to Kwant include

* Jörg Behrmann (FU Berlin)
* Paul Clisson (CEA Grenoble)
* Mathieu Istas (CEA Grenoble)
* Daniel Jaschke (CEA Grenoble)
* Bas Nijholt (TU Delft)
* Michał Nowak (TU Delft)
* Viacheslav Ostroukh (Leiden University)
* Pablo Pérez Piskunow (TU Delft)
* Tómas Örn Rosdahl (TU Delft)
* Sebastian Rubbert (TU Delft)
* Rafał Skolasiński (TU Delft)
* Adrien Sorgniard (CEA Grenoble)
* Dániel Varjas (TU Delft)

We thank Christoph Gohlke for the creation of installers for Microsoft Windows.

`CEA <http://www.cea.fr>`_ is the French Commissariat à l'énergie atomique et aux
énergies alternatives.  The CEA is the copyright holder for the contributions of
C. W. Groth, X. Waintal, and its other employees involved in Kwant.

To find out who wrote a certain part of Kwant, please use the "blame" feature of
`Git <https://git-scm.com/>`_, the version control system.


Funding
-------

Research related to Kwant was funded by

* the US Office of Naval Research,
* the European Research Council,
* the Netherlands Organisation for Scientific Research NWO (formerly NWO/FOM).
* the French National Agency for Research (ANR)
* the Future and Emerging Technologies (FET) & Information and Communication Technologies (ICT) actions
* Lawrence Golub fellowship
